Documentation
¶
Index ¶
- type Publisher
- type Publisher_Close_Call
- type Publisher_Expecter
- type Publisher_Publish_Call
- func (_c *Publisher_Publish_Call) Return(err error) *Publisher_Publish_Call
- func (_c *Publisher_Publish_Call) Run(run func(ctx context.Context, stream string, event events.Event)) *Publisher_Publish_Call
- func (_c *Publisher_Publish_Call) RunAndReturn(run func(ctx context.Context, stream string, event events.Event) error) *Publisher_Publish_Call
- type Subscriber
- type Subscriber_Close_Call
- type Subscriber_Expecter
- type Subscriber_Subscribe_Call
- func (_c *Subscriber_Subscribe_Call) Return(err error) *Subscriber_Subscribe_Call
- func (_c *Subscriber_Subscribe_Call) Run(run func(ctx context.Context, cfg events.SubscriberConfig)) *Subscriber_Subscribe_Call
- func (_c *Subscriber_Subscribe_Call) RunAndReturn(run func(ctx context.Context, cfg events.SubscriberConfig) error) *Subscriber_Subscribe_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Publisher ¶
Publisher is an autogenerated mock type for the Publisher type
func NewPublisher ¶
NewPublisher creates a new instance of Publisher. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Publisher) EXPECT ¶ added in v0.17.0
func (_m *Publisher) EXPECT() *Publisher_Expecter
type Publisher_Close_Call ¶ added in v0.17.0
Publisher_Close_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Close'
func (*Publisher_Close_Call) Return ¶ added in v0.17.0
func (_c *Publisher_Close_Call) Return(err error) *Publisher_Close_Call
func (*Publisher_Close_Call) Run ¶ added in v0.17.0
func (_c *Publisher_Close_Call) Run(run func()) *Publisher_Close_Call
func (*Publisher_Close_Call) RunAndReturn ¶ added in v0.17.0
func (_c *Publisher_Close_Call) RunAndReturn(run func() error) *Publisher_Close_Call
type Publisher_Expecter ¶ added in v0.17.0
type Publisher_Expecter struct {
// contains filtered or unexported fields
}
func (*Publisher_Expecter) Close ¶ added in v0.17.0
func (_e *Publisher_Expecter) Close() *Publisher_Close_Call
Close is a helper method to define mock.On call
func (*Publisher_Expecter) Publish ¶ added in v0.17.0
func (_e *Publisher_Expecter) Publish(ctx interface{}, stream interface{}, event interface{}) *Publisher_Publish_Call
Publish is a helper method to define mock.On call
- ctx context.Context
- stream string
- event events.Event
type Publisher_Publish_Call ¶ added in v0.17.0
Publisher_Publish_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Publish'
func (*Publisher_Publish_Call) Return ¶ added in v0.17.0
func (_c *Publisher_Publish_Call) Return(err error) *Publisher_Publish_Call
func (*Publisher_Publish_Call) Run ¶ added in v0.17.0
func (_c *Publisher_Publish_Call) Run(run func(ctx context.Context, stream string, event events.Event)) *Publisher_Publish_Call
func (*Publisher_Publish_Call) RunAndReturn ¶ added in v0.17.0
func (_c *Publisher_Publish_Call) RunAndReturn(run func(ctx context.Context, stream string, event events.Event) error) *Publisher_Publish_Call
type Subscriber ¶
Subscriber is an autogenerated mock type for the Subscriber type
func NewSubscriber ¶
func NewSubscriber(t interface {
mock.TestingT
Cleanup(func())
}) *Subscriber
NewSubscriber creates a new instance of Subscriber. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Subscriber) Close ¶
func (_mock *Subscriber) Close() error
Close provides a mock function for the type Subscriber
func (*Subscriber) EXPECT ¶ added in v0.17.0
func (_m *Subscriber) EXPECT() *Subscriber_Expecter
func (*Subscriber) Subscribe ¶
func (_mock *Subscriber) Subscribe(ctx context.Context, cfg events.SubscriberConfig) error
Subscribe provides a mock function for the type Subscriber
type Subscriber_Close_Call ¶ added in v0.17.0
Subscriber_Close_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Close'
func (*Subscriber_Close_Call) Return ¶ added in v0.17.0
func (_c *Subscriber_Close_Call) Return(err error) *Subscriber_Close_Call
func (*Subscriber_Close_Call) Run ¶ added in v0.17.0
func (_c *Subscriber_Close_Call) Run(run func()) *Subscriber_Close_Call
func (*Subscriber_Close_Call) RunAndReturn ¶ added in v0.17.0
func (_c *Subscriber_Close_Call) RunAndReturn(run func() error) *Subscriber_Close_Call
type Subscriber_Expecter ¶ added in v0.17.0
type Subscriber_Expecter struct {
// contains filtered or unexported fields
}
func (*Subscriber_Expecter) Close ¶ added in v0.17.0
func (_e *Subscriber_Expecter) Close() *Subscriber_Close_Call
Close is a helper method to define mock.On call
func (*Subscriber_Expecter) Subscribe ¶ added in v0.17.0
func (_e *Subscriber_Expecter) Subscribe(ctx interface{}, cfg interface{}) *Subscriber_Subscribe_Call
Subscribe is a helper method to define mock.On call
- ctx context.Context
- cfg events.SubscriberConfig
type Subscriber_Subscribe_Call ¶ added in v0.17.0
Subscriber_Subscribe_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Subscribe'
func (*Subscriber_Subscribe_Call) Return ¶ added in v0.17.0
func (_c *Subscriber_Subscribe_Call) Return(err error) *Subscriber_Subscribe_Call
func (*Subscriber_Subscribe_Call) Run ¶ added in v0.17.0
func (_c *Subscriber_Subscribe_Call) Run(run func(ctx context.Context, cfg events.SubscriberConfig)) *Subscriber_Subscribe_Call
func (*Subscriber_Subscribe_Call) RunAndReturn ¶ added in v0.17.0
func (_c *Subscriber_Subscribe_Call) RunAndReturn(run func(ctx context.Context, cfg events.SubscriberConfig) error) *Subscriber_Subscribe_Call